@@ -7,6 +7,13 @@ def one(session, model, **filters):
     return session.query(model).filter_by(**filters).one()
 
 
+def create(session, model, **kwargs):
+    obj = model(**kwargs)
+    session.add(obj)
+    session.commit()
+    return obj
+
+
 def get_or_create(
     session, model, create_method="", create_method_kwargs=None, **kwargs
 ):
