@@ -10,12 +10,17 @@ class CachedDict:
         return key in self._items
 
     def __iter__(self):
-        for key in self._items:
-            yield key
+        yield iter(self._items)
 
     def __next__(self):
         return next(self._items)
 
+    def keys(self):
+        yield from self._items.keys()
+
+    def values(self):
+        yield from self._items.values()
+
     def __getitem__(self, key):
         if key not in self._items:
             self._items[key] = self._get_dict_value(key)
