@@ -37,7 +37,13 @@ class TerminalColorFormatter(logging.Formatter):
     def format(self, record):
         levelname = record.levelname
         text = super(TerminalColorFormatter, self).format(record)
+
+        ip = getattr(record, "ip", None)
+        pid = getattr(record, "pid", None)
+        if ip and pid:
+            text = f"(pid={pid}, ip={ip}) " + text
+
         if record.levelname in COLORS:
-            return COLOR_SEQ % (30 + COLORS[levelname]) + text + RESET_SEQ
-        else:
-            return text
+            text = COLOR_SEQ % (30 + COLORS[levelname]) + text + RESET_SEQ
+
+        return text
