@@ -2,14 +2,11 @@
 import inspect
 from typing import Any
 
+from outflow.core.exceptions import ContextArgumentException, TaskWithKwargsException
 from outflow.core.generic.string import to_snake_case
+from outflow.core.plugin import get_plugin_name
 from outflow.core.target import Target
-
-# from outflow.core.types import TargetOutputs
-from typeguard import typechecked
-
-from .exceptions import ContextArgumentException, TaskWithKwargsException
-from ..types import outputs_type_factory, TargetOutputs
+from outflow.core.types import TargetOutputs, outputs_type_factory
 
 
 class TaskMeta(type):
@@ -25,6 +22,9 @@ class TaskMeta(type):
             [type]: the new task class
         """
 
+        if not dct.get("plugin_name", None):
+            dct["plugin_name"] = get_plugin_name()
+
         # if the new class is a subclass of task but is not an executable task
         if "run" not in dct:
             return super().__new__(cls, name, bases, dct)
@@ -88,10 +88,6 @@ class TaskMeta(type):
                 Target.output(output_name, type=output_type)(self)
             self.run.__annotations__["return"] = outputs_type_factory(return_annotation)
 
-        # add the type checking after args parsing
-        # Note: the typechecked decorator alter the function signature
-        self.run = typechecked(self.run)
-
         # convert the run function to a static method if needed
         # Note: the typechecked decorator have to be applied before the static method decorator
         if not self.with_self:
