@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 import ray
-from outflow.core.tasks.task_manager import TaskManager
+from outflow.core.tasks import TaskManager
 
 
 @ray.remote
