@@ -2,10 +2,14 @@
 import sys
 from typing import List
 
+import numpy
 import ray
 
+# from rich.progress import BarColumn, TimeElapsedColumn, TimeRemainingColumn
+
+from outflow.core.logging import logger
 from outflow.core.target import Target
-from outflow.core.tasks import Task
+from outflow.core.tasks.task import Task
 from outflow.core.types import IterateOn
 from outflow.ray.actors import MapActor
 from outflow.core.pipeline import get_pipeline_states
@@ -22,7 +26,8 @@ class MapTask(Task):
         outputs=None,
         output_name="map_output",
         num_cpus=1,
-        raise_exceptions=False
+        raise_exceptions=False,
+        actor_class=MapActor,
     ):
         super().__init__(auto_outputs=False)
         if outputs is None:
@@ -30,6 +35,8 @@ class MapTask(Task):
         else:
             self.outputs = outputs
 
+        self.actor_class = actor_class
+
         input_targets = [target for target in start.inputs.values()]
         self.inputs = {
             target.type.__name__[len(IterateOn.prefix) :]
@@ -62,9 +69,19 @@ class MapTask(Task):
 
         actor_results = list()
 
-        for index, generated_inputs in enumerate(self.generator(**map_inputs)):
+        cpu_available = ray.available_resources()["CPU"]
+
+        inputs = [i for i in self.generator(**map_inputs)]
+        batch_inputs = [
+            [el for el in sublist]
+            for sublist in numpy.array_split(inputs, cpu_available)
+        ]
+        logger.debug(f"batch inputs : {batch_inputs}")
+        # actors = list()  # TODO use this to query progress
+
+        for index, generated_inputs in enumerate(batch_inputs):
             # ensure the workflow start is the given task
-            actor = MapActor.options(num_cpus=self.num_cpus).remote(
+            actor = self.actor_class.options(num_cpus=self.num_cpus).remote(
                 loop_workflow,
                 generated_inputs,
                 index,
